@@ -78,7 +78,7 @@ class KLADRPack(ActionPack):
     @classmethod
     def get_place(cls, code):
         u"""
-        Возвращает геграфический объект в JSON-формате по коду
+        Возвращает географический объект в JSON-формате по коду
         """
         place = KladrGeo.objects.select_related(
             'parent', 'parent__parent', 'parent__parent__parent'
@@ -215,7 +215,7 @@ class StreetRowsAction(Action):
                     for field_name in fields:
                         for depth in range(self.MAX_DEPTH + 1):
                             field_condition |= Q(**{
-                                '%s%s__icontains'.format(
+                                '{0}{1}__icontains'.format(
                                     'parent__' * depth,
                                     field_name
                                 ): word
