@@ -1,13 +1,22 @@
 #coding:utf-8
 
-from django.conf import urls
+# совместимость с django 1.6
+try:
+    from django.conf.urls.defaults import patterns
+except ImportError:
+    from django.conf.urls import patterns
 
-from actions import kladr_controller, KLADRPack
+from actions import kladr_controller, KLADRPack, Kladr_DictPack
 from m3 import authenticated_user_required
 
 
 def register_actions():
-    kladr_controller.packs.append(KLADRPack())
+    kladr_controller.packs.extend(
+        (
+            KLADRPack(),
+            Kladr_DictPack()
+        )
+    )
     #kladr_controller.rebuild_patterns()
 
 
@@ -15,7 +24,7 @@ def register_urlpatterns():
     u"""
     Регистрация конфигурации урлов для приложения kladr
     """
-    return urls.defaults.patterns(
+    return patterns(
         '', (r'^m3-kladr', 'kladr.app_meta.kladr_view'),
     )
 
@@ -25,4 +34,4 @@ def register_urlpatterns():
 #===============================================================================
 @authenticated_user_required
 def kladr_view(request):
-    return kladr_controller.process_request(request) 
+    return kladr_controller.process_request(request)
